@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2010 Olaf Till
+Copyright (C) 2010-2016 Olaf Till
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
 #include <octave/oct.h>
 #include <octave/ov-struct.h>
 
+#include "error-helpers.h"
+
 DEFUN_DLD (fieldempty, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {} fieldempty (@var{s}, @var{name})\n\
@@ -28,30 +30,26 @@ Returns a logical array with same dimensions as structure @var{s}, indicating wh
 {
   std::string fname ("fieldempty");
 
+  octave_value_list err_retval;
+
   if (args.length () != 2)
     {
       print_usage ();
-      return octave_value_list ();
+      return err_retval;
     }
 
-  octave_map s = args(0).map_value ();
-  if (error_state)
-    {
-      error ("%s: first argument must be a structure", fname.c_str ());
-      return octave_value_list ();
-    }
+  octave_map s;
+  CHECK_ERROR (s = args(0).map_value (), err_retval,
+               "%s: first argument must be a structure", fname.c_str ());
 
-  std::string name = args(1).string_value ();
-  if (error_state)
-    {
-      error ("%s: second argument must be a string", fname.c_str ());
-      return octave_value_list ();
-    }
+  std::string name;
+  CHECK_ERROR (name = args(1).string_value (), err_retval,
+               "%s: second argument must be a string", fname.c_str ());
 
   if (! s.contains (name))
     {
       error ("%s: no such field", fname.c_str ());
-      return octave_value_list ();
+      return err_retval;
     }
 
   dim_vector sdims = s.dims ();
